NAME
Encode::DosHebrew - DOS Hebrew Encoding
SYNOPSIS
use Encode;
use Encode::DosHebrew;
use File::BOM;
# Hebrew word for "newspaper"
my $dosTxt = "\x92\xA0\xFA\xED\x8F\xA7";
open $outF, ">:utf8:via(File::BOM)", 'unicode.txt'
or die "can't write: $!\n";
print $outF decode('DosHebrew', $dosTxt), "\n";
close $outF;
ABSTRACT
This module implements a DOS 8-bit encoding of Hebrew, which includes vowels (nikud), as well as pointed (dagesh) consonants, in addition to the standard consonants. It is a superset of Code page 862 (which includes only consonants).
Although data files exist that use this "DosHebrew" encoding, its origin is unclear, and there are no known standards which describe it.
BUGS
Only the "decode" function is implemented at this time.
DESCRIPTION
To find how to use this module in detail, see Encode.
SEE ALSO
Encode
AUTHOR
Tzadik Vanderhoof, <tzadikv@cpan.org>